function [x,y,r0,alpha0] = UWgeodesic(s,theta,npts,R)
%GEODESIC: computes a discretized version of the unique curve 
% \gamma (s,\theta,t) in the Poincare disk of radius R >= 1 such that 
% \gamma (s,\theta, 0) = s (\cos\theta, \sin\theta)
% \dot\gamma (s,\theta,0) = (-\sin\theta, \cos\theta)
%
% OUTPUTS: 
%     - x,y: the coordinates of the points of that curve included in the
%     unit disk
%     - r0: when s is not 0, radius of the circle
%     - alpha0: when s is not 0, 1/2 of the aperture of the arc-circle 
%     describing the curve

if R<1,
    error('R should be greater than 1.')
end

if abs(s) > 1,
    error(['s = ',num2str(s),', too large !']);
end

if s == 0, % construct a straight line of direction (-\sin\theta, \cos\theta)
    
    x = -sin(theta)*(-1+1/npts:2/npts:1-1/npts);
    y = cos(theta)*(-1+1/npts:2/npts:1-1/npts);
    
elseif abs(s)<=.9 % construct an arc circle
    
    r0 = %%% FILL OUT; % radius of the circle 
    y0 = %%% FILL OUT; % distance of the center from zero
    
    % range of angles of the arc-circle
    alpha0 = %%% FILL OUT 
    
    alphamin = %%% FILL OUT
    alphamax = %%% FILL OUT
    
    dalpha = (alphamax-alphamin)/npts;
    alphas = alphamin+dalpha/2:dalpha:alphamax-dalpha/2;
    
    x = %%% FILL OUT
    y = %%% FILL OUT
else % if s is too close to 1, return empty list
    x=[];
    y=[];
    r0=0;
    alpha0=0;
end

end