function hRT = hyperRadon(f, ss, thetas, npts, R)
%HYPERRADON: computes the Radon transform of a function supported in the
%unit disk, where the curves are given by the geometry of the Poincare disk
%of radius R


n = size(f,1);
xs = -1+1/n:2/n:1-1/n;

nss = length(ss);
nth = length(thetas);
hRT = zeros(nss,nth);

for j=1:nss,
    for k=1:nth,
        % compute the curve over which to integrate
        [x,y,r0,alpha0] = geodesic(ss(j),thetas(k),npts, R);

        % compute the curve integral using a bilinear interpolation (vectorized)
        x_rs = n/2 * (x + 1.-1/n);
        y_rs = n/2 * (y + 1.-1/n);
        i0 = floor(y_rs);
        j0 = floor(x_rs);
        xbar = x_rs - j0;
        ybar = y_rs - i0;
        i0 = max(min(i0 + 1,n-1),1);
        j0 = max(min(j0 + 1,n-1),1);
        
        hRT(j,k) = sum( f( n*(j0-1) + i0) .* (1.-xbar) .* (1.-ybar) ...
            + f( n*(j0-1) + i0+1) .* ybar .* (1.-xbar) ...
            + f( n*(j0+1-1) + i0) .* xbar .* (1.-ybar) ...
            + f( n*(j0+1-1) + i0+1) .* xbar .* ybar );
        
        % compute the curve integral (non-vectorized)                
%         for p=1:length(x),
%             if x(p)*x(p) + y(p)*y(p) <= .81,
%                 x_rs = n/2. * (x(p) + 1.-1./n);
%                 y_rs = n/2. * (y(p) + 1.-1./n);
%                 i0 = floor(y_rs);
%                 j0 = floor(x_rs);
%                 xbar = x_rs - j0;
%                 ybar = y_rs - i0;
%                 i0 = i0+1; j0=j0+1;
%                 hRT(j,k) = hRT(j,k) ...
%                     + f(i0, j0) * (1.-xbar) * (1.-ybar) ...
%                     + f(i0+1, j0) * ybar * (1.-xbar) ...
%                     + f(i0, j0+1) * xbar * (1.-ybar) ...
%                     + f(i0+1, j0+1) * xbar * ybar;
%             end
%         end

        hRT(j,k) = (2*alpha0*abs(r0))*hRT(j,k)/npts;
    end
end

end